@@ -3,7 +3,7 @@ package Algorithm::RectanglesContainingDot_XS;
 use strict;
 use warnings;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 require XSLoader;
 XSLoader::load('Algorithm::RectanglesContainingDot_XS', $VERSION);
@@ -13,22 +13,25 @@ __END__
 
 =head1 NAME
 
-Algorithm::RectanglesContainingDot_XS - XS implementation of Algorithm::RectanglesContainingDot
+Algorithm::RectanglesContainingDot_XS - C/XS implementation of Algorithm::RectanglesContainingDot
 
 =head1 SYNOPSIS
 
-  # use Algorithm::RectanglesContainingDot;
-  use Algorithm::RectanglesContainingDot_XS;
+  # install Algorithm::RectanglesContainingDot_XS and...
+  use Algorithm::RectanglesContainingDot;
 
 =head1 DESCRIPTION
 
-This module is a drop in replacement for
-L<Algorithm::RectanglesContainingDot> written in C/XS and so much
-faster (around 30 times faster!).
+This module implements the same algorithm as
+L<Algorithm::RectanglesContainingDot> in C/XS and so it is much faster
+(around 30 times faster!).
+
+L<Algorithm::RectanglesContainingDot> will use this implementation
+automatically when available.
 
 =head1 SEE ALSO
 
-L<Algorithm::RectanglesContainingDot> to learn how to use this module.
+L<Algorithm::RectanglesContainingDot>.
 
 =head1 AUTHOR
 
